@@ -21,14 +21,15 @@ ipv6re = ("^(([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:)"
 ipv4v6re = "{0}|{1}".format(ipv4re, ipv6re)
 
 
-def build_schema(schema, add_meta=True, type_="object"):
+def build_schema(schema, add_meta=True, type_="object",
+                 additionalProperties=False):
     """
     Adds a few necessary embelishments to any schema
     """
 
     schema["$schema"] = "http://json-schema.org/draft-04/schema#"
     schema["type"] = type_
-    schema["additionalProperties"] = False
+    schema["additionalProperties"] = additionalProperties
     if add_meta:
         schema["properties"][F.META] = _MetaSchema
     return schema
@@ -104,12 +105,13 @@ DomainSchema = build_schema({
     }
 })
 
-# a bucket for any kinds of misc settings a Job might need
+# Special schema:
+# a bucket for any kinds of misc settings a Job might need: user-agent strings,
+# previous file hashes, previous IP addresses
 JobsettingsSchema = build_schema({
     "properties": {
-        F.JOB_SETTINGS: {"type": "object"},
-    }
-})
+    },
+}, add_meta=False, additionalProperties=True)
 
 GeoipSchema = build_schema({
     "properties": {
